@@ -24,10 +24,12 @@ from brax.envs import fast
 from brax.envs import fetch
 from brax.envs import grasp
 from brax.envs import halfcheetah
+from brax.envs import hopper
 from brax.envs import humanoid
 from brax.envs import reacher
 from brax.envs import reacherangle
 from brax.envs import ur5e
+from brax.envs import walker2d
 from brax.envs import wrappers
 from brax.envs.env import Env, State, Wrapper
 import gym
@@ -38,10 +40,12 @@ _envs = {
     'fetch': fetch.Fetch,
     'grasp': grasp.Grasp,
     'halfcheetah': halfcheetah.Halfcheetah,
+    'hopper': hopper.Hopper,
     'humanoid': humanoid.Humanoid,
     'reacher': reacher.Reacher,
     'reacherangle': reacherangle.ReacherAngle,
     'ur5e': ur5e.Ur5e,
+    'walker2d': walker2d.Walker2d,
 }
 
 
