@@ -28,15 +28,15 @@ class Fetch(env.Env):
 
   def __init__(self, **kwargs):
     super().__init__(_SYSTEM_CONFIG, **kwargs)
-    self.target_idx = self.sys.body_idx['Target']
-    self.torso_idx = self.sys.body_idx['Torso']
+    self.target_idx = self.sys.body.index['Target']
+    self.torso_idx = self.sys.body.index['Torso']
     self.target_radius = 2
     self.target_distance = 15
 
   def reset(self, rng: jnp.ndarray) -> env.State:
     qp = self.sys.default_qp()
     rng, target = self._random_target(rng)
-    pos = jax.ops.index_update(qp.pos, jax.ops.index[self.target_idx], target)
+    pos = qp.pos.at[self.target_idx].set(target)
     qp = qp.replace(pos=pos)
     info = self.sys.info(qp)
     obs = self._get_obs(qp, info)
@@ -89,7 +89,7 @@ class Fetch(env.Env):
     # teleport any hit targets
     rng, target = self._random_target(state.info['rng'])
     target = jnp.where(target_hit, target, qp.pos[self.target_idx])
-    pos = jax.ops.index_update(qp.pos, jax.ops.index[self.target_idx], target)
+    pos = qp.pos.at[self.target_idx].set(target)
     qp = qp.replace(pos=pos)
     state.info.update(rng=rng)
     return state.replace(qp=qp, obs=obs, reward=reward)
