@@ -32,13 +32,13 @@ class Reacher(env.Env):
 
   def __init__(self, **kwargs):
     super().__init__(_SYSTEM_CONFIG, **kwargs)
-    self.target_idx = self.sys.body_idx['target']
-    self.arm_idx = self.sys.body_idx['body1']
+    self.target_idx = self.sys.body.index['target']
+    self.arm_idx = self.sys.body.index['body1']
 
   def reset(self, rng: jnp.ndarray) -> env.State:
     qp = self.sys.default_qp()
     _, target = self._random_target(rng)
-    pos = jax.ops.index_update(qp.pos, jax.ops.index[self.target_idx], target)
+    pos = qp.pos.at[self.target_idx].set(target)
     qp = qp.replace(pos=pos)
     info = self.sys.info(qp)
     obs = self._get_obs(qp, info)
@@ -69,7 +69,7 @@ class Reacher(env.Env):
     """Egocentric observation of target and arm body."""
 
     # some pre-processing to pull joint angles and velocities
-    (joint_angle,), _ = self.sys.joint_revolute.angle_vel(qp)
+    (joint_angle,), _ = self.sys.joints[0].angle_vel(qp)
 
     # qpos:
     # x,y coord of target
