@@ -15,11 +15,34 @@
 """General-purpose file interface to support different backing file APIs."""
 
 
+import glob
+import os
+from typing import List
+
+
+def Glob(pattern: str) -> List[str]:
+  return glob.glob(pattern)
+
+
+def Exists(pathname: str) -> bool:
+  """Check if a path exists."""
+  exist = None
+  if exist is None:
+    exist = os.path.exists(pathname)
+  return exist
+
+
+def MakeDirs(dirname: str):
+  """Make directory if it doesn't exist."""
+  exist_dir = False
+  if not exist_dir:
+    os.makedirs(dirname, exist_ok=True)
+
 
 class File:
   """General purpose file resource."""
 
-  def __init__(self, fileName, mode='r'):
+  def __init__(self, fileName: str, mode='r'):
     self.f = None
     if not self.f:
       self.f = open(fileName, mode)
