@@ -15,20 +15,20 @@
 """Tests for brax.envs.grasp."""
 
 from absl.testing import absltest
-import jax
-import jax.numpy as np
 from brax import envs
+import jax
+import jax.numpy as jnp
 
 
 class GraspTest(absltest.TestCase):
 
   def testGrasp(self):
     env = envs.create('grasp')
-    grasp_action = np.array([
-        -.4, -.35, -0., -1,  # gripper arm 1
-        .4, .35, 0., 1,  # gripper arm 2
-        .4, .35, 0., 1,  # gripper arm 3
-        .4, .35, 0., 1,  # gripper arm 4
+    grasp_action = jnp.array([
+        -.4, -.35, -1., -0.,  # gripper arm 1
+        .4, .35, 1., 0,  # gripper arm 2
+        .4, .35, 1., 0,  # gripper arm 3
+        .4, .35, 1., 0,  # gripper arm 4
         0., 0., -.9  # position action
     ])
 
@@ -38,7 +38,7 @@ class GraspTest(absltest.TestCase):
     for _ in range(500):
       state = jit_env_step(state, grasp_action)
 
-    self.assertGreater(state.qp.pos[1, 2], 1.47)  # ball lifted off ground
+    self.assertGreater(state.qp.pos[1, 2], 1.36)  # ball lifted off ground
     self.assertLess(state.qp.ang[1, 2], .01)  # ball not rolling
 
 
