@@ -16,10 +16,10 @@
 
 from absl.testing import absltest
 from absl.testing import parameterized
-from flax import serialization
-import jax
 from brax import envs
 from brax.training import ppo
+from flax import serialization
+import jax
 
 
 class PPOTest(parameterized.TestCase):
@@ -57,7 +57,7 @@ class PPOTest(parameterized.TestCase):
 
     # Compute one action.
     state = env.reset(jax.random.PRNGKey(0))
-    action = inference(decoded_params, state.obs, state.rng)
+    action = inference(decoded_params, state.obs, jax.random.PRNGKey(0))
     env.step(state, action)
 
 
