@@ -14,14 +14,14 @@
 
 """Mujoco XML model loader for Brax."""
 
+import dataclasses
 from typing import Any, AnyStr, Dict, List, Optional
 
 from absl import logging
-import dataclasses
+from brax.physics import config_pb2
 from dm_control import mjcf
 from dm_control.mjcf import constants
 import numpy as np
-from brax.physics import config_pb2
 from transforms3d import euler
 from transforms3d import quaternions
 from transforms3d import utils as transform_utils
@@ -70,6 +70,11 @@ def _vec(v: Vector3d) -> config_pb2.Vector3:
   return config_pb2.Vector3(x=x, y=y, z=z)
 
 
+def _np_vec(v: config_pb2.Vector3) -> Vector3d:
+  """Converts a Vector3 to a numpy array."""
+  return np.array([v.x, v.y, v.z])
+
+
 def _euler(q: Optional[Quaternion]) -> config_pb2.Vector3:
   """Converts the quaternion to Euler angles in degrees."""
   if q is None:
@@ -96,15 +101,17 @@ def _rot_quat(u: Vector3d, v: Vector3d) -> Quaternion:
   return quaternions.axangle2quat(axis, angle)
 
 
-def _create_joint(name: str,
-                  parent_body_name: str,
-                  child_body_name: str,
-                  parent_offset: Optional[Vector3d] = None,
-                  child_offset: Optional[Vector3d] = None,
-                  axis: Optional[Vector3d] = None,
-                  stiffness: float = DEFAULT_STIFFNESS,
-                  joint_range: Optional[Vector] = None,
-                  rotation: Optional[Quaternion] = None) -> config_pb2.Joint:
+def _create_joint(
+    name: str,
+    parent_body_name: str,
+    child_body_name: str,
+    parent_offset: Optional[Vector3d] = None,
+    child_offset: Optional[Vector3d] = None,
+    axis: Optional[Vector3d] = None,
+    stiffness: float = DEFAULT_STIFFNESS,
+    joint_range: Optional[Vector] = None,
+    rotation: Optional[Quaternion] = None,
+    reference_rotation: Optional[Quaternion] = None) -> config_pb2.Joint:
   """Returns a (revolute) joint with the specified properties."""
   if axis is None:
     # Default axis of rotation.
@@ -124,14 +131,16 @@ def _create_joint(name: str,
       child_offset=_vec(child_offset) if child_offset is not None else None,
       stiffness=stiffness,
       rotation=_euler(rotation),
-      angle_limit=[angle_limit])
+      angle_limit=[angle_limit],
+      reference_rotation=_euler(reference_rotation))
 
 
 def _create_fixed_joint(name: str,
                         parent_body_name: str,
                         child_body_name: str,
                         parent_offset: Optional[Vector3d] = None,
-                        rotation: Optional[Quaternion] = None):
+                        rotation: Optional[Quaternion] = None,
+                        reference_rotation: Optional[Quaternion] = None):
   """Returns a fixed joint."""
   # Brax does not support such joints. Instead we use a revolute joint with a
   # high stiffness and zero angle range.
@@ -141,13 +150,18 @@ def _create_fixed_joint(name: str,
       child_body_name,
       stiffness=DEFAULT_STIFFNESS,
       parent_offset=parent_offset,
-      rotation=rotation)
+      rotation=rotation,
+      reference_rotation=reference_rotation)
 
 
 class MujocoConverter(object):
   """Converts a Mujoco model to a Brax config."""
 
-  def __init__(self, xml_string: AnyStr, add_collision_pairs: bool = False):
+  def __init__(self,
+               xml_string: AnyStr,
+               add_collision_pairs: bool = False,
+               ignore_unsupported_joints: bool = False,
+               add_joint_to_nearest_body: bool = False):
     """Creates a MujocoConverter.
 
     Args:
@@ -156,11 +170,17 @@ class MujocoConverter(object):
         be added automatically based on the structure of the model and Mujoco
         collision mask settings. See
         http://www.mujoco.org/book/computation.html#Collision.
+      ignore_unsupported_joints: If true, then unsupported joints, e.g. slide,
+        will be ignored, otherwise they raise an exception.
+      add_joint_to_nearest_body: Adds a joint to the nearest (child)body when
+        multiple geometries of a Mujoco body are represented as separate bodies.
     """
     mjcf_model = mjcf.from_xml_string(xml_string, escape_separators=True)
     self._mjcf_model = mjcf_model
     config = config_pb2.Config()
     self._config = config
+    self._ignore_unsupported_joints = ignore_unsupported_joints
+    self._add_joint_to_nearest_body = add_joint_to_nearest_body
     # Brax uses local coordinates. If global coordinates are used in the
     # Mujoco model, we convert them to local ones.
     self._uses_global = mjcf_model.compiler.coordinate == 'global'
@@ -216,11 +236,18 @@ class MujocoConverter(object):
 
   def _get_rotation(self, elem: MjcfElement) -> Quaternion:
     """Returns the rotation quaternion of the Mujoco element."""
-    if _is_worldbody(elem) or elem.axisangle is None:
+    if _is_worldbody(elem):
       return quaternions.qeye()
-    axisangle = elem.axisangle
-    return quaternions.axangle2quat(axisangle[0:3],
-                                    self._maybe_to_radian(axisangle[3]))
+    if elem.euler is not None:
+      return euler.euler2quat(
+          self._maybe_to_radian(elem.euler[0]),
+          self._maybe_to_radian(elem.euler[1]),
+          self._maybe_to_radian(elem.euler[2]))
+    if elem.axisangle is not None:
+      axisangle = elem.axisangle
+      return quaternions.axangle2quat(axisangle[0:3],
+                                      self._maybe_to_radian(axisangle[3]))
+    return quaternions.qeye()
 
   def _get_mass(self, geom: MjcfElement, volume: float) -> float:
     """Returns the mass of the geometry based on its volume."""
@@ -334,12 +361,18 @@ class MujocoConverter(object):
       body.name = mujoco_body.name if mujoco_body.name else f'$body{body_idx}'
     logging.info('Body %s', body.name)
     geoms = mujoco_body.geom if hasattr(mujoco_body, 'geom') else []
-    # We add the first geometry to the body itself.
-    geom = geoms[0]
+    if not geoms:
+      # Except worldbody, we expect the bodies to have a geometry. We add a
+      # dummy one if that is not the case.
+      geom = mujoco_body.add('geom', pos=[0, 0, 0], type='sphere', size=[0.01])
+    else:
+      # We add the first geometry to the body itself.
+      geom = geoms[0]
     if geom.name and body.name == constants.WORLDBODY:
       # Using the name of the geometry is less confusing for worldbody. It won't
       # use referred to in joints or actuators.
       body.name = geom.name
+    reference_rotation = self._get_rotation(mujoco_body)
     geom_collider = self._geom_to_collider(geom)
     body.mass = geom_collider.mass
     body.inertia.CopyFrom(_vec(DEFAULT_INERTIA))
@@ -359,7 +392,12 @@ class MujocoConverter(object):
               colliders=[child_geom_collider.collider],
               mass=child_geom_collider.mass,
               inertia=_vec(DEFAULT_INERTIA)))
-      config.joints.append(_create_fixed_joint(geom_name, body.name, geom_name))
+      config.joints.append(
+          _create_fixed_joint(
+              geom_name,
+              body.name,
+              geom_name,
+              reference_rotation=reference_rotation))
       geom_colliders.append(child_geom_collider)
       # We use the same parent body name to ensure that multiple geometries of a
       # body do not collide with each other.
@@ -386,7 +424,8 @@ class MujocoConverter(object):
               parent_body.name,
               body.name,
               parent_offset=parent_offset,
-              rotation=rotation))
+              rotation=rotation,
+              reference_rotation=reference_rotation))
 
     for child_mujoco_body in mujoco_body.body:
       self._add_body(child_mujoco_body, body)
@@ -395,24 +434,31 @@ class MujocoConverter(object):
                   geom_colliders: List[GeomCollider],
                   geom_bodies: List[config_pb2.Body]):
     """Adds the joints of the body to the config."""
+    reference_rotation = self._get_rotation(mujoco_body)
     local_mujoco_body_pos = self._get_position(mujoco_body)
     for joint in mujoco_body.joint:
       if joint.type == 'free':
         continue
       if joint.type != 'hinge':
+        if self._ignore_unsupported_joints:
+          return
         raise ValueError(
             f'Unsupported joint type {joint.type} for {joint.name}')
-      # When a body has multiple geometries, all except the first one to are
-      # moved to auxiliary child bodies (above), therefore we need to find the
-      # one that the joint is actually connected with. For now, we use the
-      # distance as a proxy.
       min_i = 0
-      min_d = None
       local_joint_pos = self._get_position(joint)
-      for i, geom_collider in enumerate(geom_colliders):
-        d = np.linalg.norm(local_joint_pos)
-        if min_d is None or min_d > d:
-          min_i, min_d = i, d
+      if self._add_joint_to_nearest_body:
+        # When a body has multiple geometries, all except the first one to are
+        # moved to auxiliary child bodies (above), therefore we need to find the
+        # one that the joint is actually connected with. For now, we use the
+        # distance as a proxy.
+        min_d = None
+        for i, geom_collider in enumerate(geom_colliders):
+          d = np.linalg.norm(local_joint_pos -
+                             _np_vec(geom_collider.collider.position))
+          if min_d is None or min_d > d:
+            min_i, min_d = i, d
+            logging.info('Distance to %s is %g.', geom_bodies[min_i].name,
+                         min_d)
       attachment_body = geom_bodies[min_i]
       logging.info('Joint %s connects %s to %s.', joint.name, parent_body.name,
                    attachment_body.name)
@@ -437,7 +483,8 @@ class MujocoConverter(object):
               child_offset,
               axis=joint.axis,
               stiffness=stiffness,
-              joint_range=joint.range))
+              joint_range=joint.range,
+              reference_rotation=reference_rotation))
 
   def _add_actuators(self):
     """Adds the actuators to the config."""
